#
# PySNMP MIB module ROHC-RTP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ROHC-RTP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:27:06 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ConstraintsUnion")
( rohcContextCID, rohcChannelID, ) = mibBuilder.importSymbols("ROHC-MIB", "rohcContextCID", "rohcChannelID")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( Gauge32, IpAddress, mib_2, Unsigned32, Counter32, iso, MibIdentifier, TimeTicks, ModuleIdentity, Bits, Counter64, Integer32, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, ObjectIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Gauge32", "IpAddress", "mib-2", "Unsigned32", "Counter32", "iso", "MibIdentifier", "TimeTicks", "ModuleIdentity", "Bits", "Counter64", "Integer32", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "ObjectIdentity")
( TruthValue, TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TruthValue", "TextualConvention", "DisplayString")
rohcRtpMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 114)).setRevisions(("2004-06-03 00:00",))
if mibBuilder.loadTexts: rohcRtpMIB.setLastUpdated('200406030000Z')
if mibBuilder.loadTexts: rohcRtpMIB.setOrganization('IETF Robust Header Compression Working Group')
if mibBuilder.loadTexts: rohcRtpMIB.setContactInfo('WG charter:\n          http://www.ietf.org/html.charters/rohc-charter.html\n\n        Mailing Lists:\n          General Discussion: rohc@ietf.org\n          To Subscribe: rohc-request@ietf.org\n          In Body: subscribe your_email_address\n\n        Editor:\n          Juergen Quittek\n          NEC Europe Ltd.\n          Network Laboratories\n          Kurfuersten-Anlage 36\n          69221 Heidelberg\n          Germany\n          Tel: +49 6221 90511-15\n          EMail: quittek@netlab.nec.de')
if mibBuilder.loadTexts: rohcRtpMIB.setDescription('This MIB module defines a set of objects for monitoring\n         and configuring RObust Header Compression (ROHC).\n         The objects are specific to ROHC RTP (profile 0x0001),\n         ROHC UDP (profile 0x0002), and ROHC ESP (profile 0x0003)\n         defined in RFC 3095 and for the ROHC LLA profile (profile\n         0x0005) defined in RFC 3242.\n\n         Copyright (C) The Internet Society (2004). The\n         initial version of this MIB module was published\n         in RFC 3816. For full legal notices see the RFC\n         itself or see:\n         http://www.ietf.org/copyrights/ianamib.html')
rohcRtpObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 114, 1))
rohcRtpConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 114, 2))
rohcRtpContextTable = MibTable((1, 3, 6, 1, 2, 1, 114, 1, 1), )
if mibBuilder.loadTexts: rohcRtpContextTable.setDescription('This table lists and describes RTP profile specific\n         properties of compressor contexts and decompressor\n         contexts.  It extends the rohcContextTable of the\n         ROHC-MIB module.')
rohcRtpContextEntry = MibTableRow((1, 3, 6, 1, 2, 1, 114, 1, 1, 1), ).setIndexNames((0, "ROHC-MIB", "rohcChannelID"), (0, "ROHC-MIB", "rohcContextCID"))
if mibBuilder.loadTexts: rohcRtpContextEntry.setDescription('An entry describing a particular context.')
rohcRtpContextState = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("initAndRefresh", 1), ("firstOrder", 2), ("secondOrder", 3), ("noContext", 4), ("staticContext", 5), ("fullContext", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextState.setDescription('State of the context as defined in RFC 3095.  States\n         initAndRefresh(1), firstOrder(2), and secondOrder(3)\n         are states of compressor contexts, states noContext(4),\n         staticContext(5) and fullContext(6) are states of\n         decompressor contexts.')
rohcRtpContextMode = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("unidirectional", 1), ("optimistic", 2), ("reliable", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextMode.setDescription('Mode of the context.')
rohcRtpContextAlwaysPad = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 5), TruthValue().clone('false')).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextAlwaysPad.setDescription('Boolean, only applicable to compressor contexts using the\n\n         LLA profile.  If its value is true, the compressor must\n         pad every RHP packet with a minimum of one octet ROHC\n         padding.\n\n         The value of this object is only valid for LLA profiles,\n         i.e., if the corresponding rohcProfile has a value of\n         0x0005.  If the corresponding rohcProfile has a value\n         other than 0x0005, then this object MUST NOT be\n         instantiated.')
rohcRtpContextLargePktsAllowed = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 6), TruthValue().clone('true')).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextLargePktsAllowed.setDescription('Boolean, only applicable to compressor contexts using the\n         LLA profile.  It specifies how to handle packets that do\n         not fit any of the preferred packet sizes specified.  If\n         its value is true, the compressor must deliver the larger\n         packet as-is and must not use segmentation.  If it is set\n         to false, the ROHC segmentation scheme must be used to\n         split the packet into two or more segments, and each\n         segment must further be padded to fit one of the preferred\n         packet sizes.\n\n         The value of this object is only valid for LLA profiles,\n         i.e., if the corresponding rohcProfile has a value of\n         0x0005.  If the corresponding rohcProfile has a value\n         other than 0x0005, then this object MUST NOT be\n         instantiated.')
rohcRtpContextVerifyPeriod = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 7), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextVerifyPeriod.setDescription('This object is only applicable to compressor contexts\n         using the LLA profile.  It specifies the minimum frequency\n         with which a packet validating the context must be sent.\n         This tells the compressor that a packet containing a CRC\n\n         field must be sent at least once every N packets, where N\n         is the value of the object.  A value of 0 indicates that\n         periodical verifications are disabled.\n\n         The value of this object is only valid for LLA profiles,\n         i.e., if the corresponding rohcProfile has a value of\n         0x0005.  If the corresponding rohcProfile has a value\n         other than 0x0005, then this object MUST NOT be\n         instantiated.')
rohcRtpContextSizesAllowed = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 8), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextSizesAllowed.setDescription('The value of this object is only valid for decompressor\n         contexts, i.e., if rohcInstanceType of the corresponding\n         rohcContextEntry has the value decompressor(2).  For\n         compressor contexts where rohcInstanceType has the value\n         compressor(1), this object MUST NOT be instantiated.\n\n         This object contains the number of different packet sizes\n         that may be used in the context.')
rohcRtpContextSizesUsed = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 9), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextSizesUsed.setDescription('The value of this object is only valid for decompressor\n         contexts, i.e., if rohcInstanceType of the corresponding\n         rohcContextEntry has the value decompressor(2).  For\n         compressor contexts where rohcInstanceType has the value\n         compressor(1), this object MUST NOT be instantiated.\n\n         This object contains the number of different packet sizes\n         that are used in the context.')
rohcRtpContextACKs = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextACKs.setDescription('The number of all positive feedbacks (ACK) sent or\n         received in this context, respectively.\n\n         Discontinuities in the value of this counter can\n         occur at re-initialization of the management\n         system, and at other times as indicated by the\n         value of ifCounterDiscontinuityTime.  For checking\n         ifCounterDiscontinuityTime, the interface index is\n         required.  It can be determined by reading the\n         rohcChannelTable of the ROHC-MIB.')
rohcRtpContextNACKs = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextNACKs.setDescription('The number of all dynamic negative feedbacks (ACK) sent\n         or received in this context, respectively.\n\n         Discontinuities in the value of this counter can\n         occur at re-initialization of the management\n         system, and at other times as indicated by the\n         value of ifCounterDiscontinuityTime.  For checking\n         ifCounterDiscontinuityTime, the interface index is\n         required.  It can be determined by reading the\n         rohcChannelTable of the ROHC-MIB.')
rohcRtpContextSNACKs = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextSNACKs.setDescription('The number of all static negative feedbacks (ACK) sent\n         or received in this context, respectively.\n\n         Discontinuities in the value of this counter can\n         occur at re-initialization of the management\n\n         system, and at other times as indicated by the\n         value of ifCounterDiscontinuityTime.  For checking\n         ifCounterDiscontinuityTime, the interface index is\n         required.  It can be determined by reading the\n         rohcChannelTable of the ROHC-MIB.')
rohcRtpContextNHPs = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextNHPs.setDescription('This object is only applicable to contexts using the\n         LLA profile.  It contains the number of all no-header\n         packets (NHP) sent or received in this context,\n         respectively.\n\n         Discontinuities in the value of this counter can\n         occur at re-initialization of the management\n         system, and at other times as indicated by the\n         value of ifCounterDiscontinuityTime.  For checking\n         ifCounterDiscontinuityTime, the interface index is\n         required.  It can be determined by reading the\n         rohcChannelTable of the ROHC-MIB.\n\n         The value of this object is only valid for LLA profiles,\n         i.e., if the corresponding rohcProfile has a value of\n         0x0005.  If the corresponding rohcProfile has a value\n         other than 0x0005, then this object MUST NOT be\n         instantiated.')
rohcRtpContextCSPs = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextCSPs.setDescription('This object is only applicable to contexts using the\n         LLA profile.  It contains the number of all context\n         synchronization packets (CSP) sent or received in this\n         context, respectively.\n\n         Discontinuities in the value of this counter can\n         occur at re-initialization of the management\n\n         system, and at other times as indicated by the\n         value of ifCounterDiscontinuityTime.  For checking\n         ifCounterDiscontinuityTime, the interface index is\n         required.  It can be determined by reading the\n         rohcChannelTable of the ROHC-MIB.\n\n         The value of this object is only valid for LLA profiles,\n         i.e., if the corresponding rohcProfile has a value of\n         0x0005.  If the corresponding rohcProfile has a value\n         other than 0x0005, then this object MUST NOT be\n         instantiated.')
rohcRtpContextCCPs = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextCCPs.setDescription('This object is only applicable to contexts using the\n         LLA profile.  It contains the number of all context check\n         packets (CCP) sent or received in this context,\n         respectively.\n\n         Discontinuities in the value of this counter can\n         occur at re-initialization of the management\n         system, and at other times as indicated by the\n         value of ifCounterDiscontinuityTime.  For checking\n         ifCounterDiscontinuityTime, the interface index is\n         required.  It can be determined by reading the\n         rohcChannelTable of the ROHC-MIB.\n\n         The value of this object is only valid for LLA profiles,\n         i.e., if the corresponding rohcProfile has a value of\n         0x0005.  If the corresponding rohcProfile has a value\n         other than 0x0005, then this object MUST NOT be\n         instantiated.')
rohcRtpContextPktsLostPhysical = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextPktsLostPhysical.setDescription('This object is only applicable to decompressor contexts\n\n         using the LLA profile.  It contains the number of physical\n         packet losses on the link between compressor and\n         decompressor, that have been indicated to the decompressor.\n\n         Discontinuities in the value of this counter can\n         occur at re-initialization of the management\n         system, and at other times as indicated by the\n         value of ifCounterDiscontinuityTime.  For checking\n         ifCounterDiscontinuityTime, the interface index is\n         required.  It can be determined by reading the\n         rohcChannelTable of the ROHC-MIB.\n\n         The value of this object is only valid for LLA profiles,\n         i.e., if the corresponding rohcProfile has a value of\n         0x0005.  If the corresponding rohcProfile has a value\n         other than 0x0005, then this object MUST NOT be\n         instantiated.')
rohcRtpContextPktsLostPreLink = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 1, 1, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpContextPktsLostPreLink.setDescription('This object is only applicable to decompressor contexts\n         using the LLA profile.  It contains the number of pre-link\n         packet losses on the link between compressor and\n         decompressor, that have been indicated to the decompressor.\n\n         Discontinuities in the value of this counter can\n         occur at re-initialization of the management\n         system, and at other times as indicated by the\n         value of ifCounterDiscontinuityTime.  For checking\n         ifCounterDiscontinuityTime, the interface index is\n         required.  It can be determined by reading the\n         rohcChannelTable of the ROHC-MIB.\n\n         The value of this object is only valid for LLA profiles,\n         i.e., if the corresponding rohcProfile has a value of\n         0x0005.  If the corresponding rohcProfile has a value\n         other than 0x0005, then this object MUST NOT be\n         instantiated.')
rohcRtpPacketSizeTable = MibTable((1, 3, 6, 1, 2, 1, 114, 1, 2), )
if mibBuilder.loadTexts: rohcRtpPacketSizeTable.setDescription('This table lists all allowed, preferred, and used packet\n         sizes per compressor context and channel.\n\n         Note, that the sizes table represents implementation\n         parameters that are suggested by RFC 3095 and/or RFC 3242,\n         but that are not mandatory.')
rohcRtpPacketSizeEntry = MibTableRow((1, 3, 6, 1, 2, 1, 114, 1, 2, 1), ).setIndexNames((0, "ROHC-MIB", "rohcChannelID"), (0, "ROHC-MIB", "rohcContextCID"), (0, "ROHC-RTP-MIB", "rohcRtpPacketSize"))
if mibBuilder.loadTexts: rohcRtpPacketSizeEntry.setDescription('An entry of a particular packet size.')
rohcRtpPacketSize = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 2, 1, 3), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: rohcRtpPacketSize.setDescription('A packet size used as index.')
rohcRtpPacketSizePreferred = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 2, 1, 4), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpPacketSizePreferred.setDescription('This object is only applicable to compressor contexts\n         using the LLA profile.  When retrieved, it will have\n         the value true(1) if the packet size is preferred.\n         Otherwise, its value will be false(2).\n\n         The value of this object is only valid for LLA profiles,\n         i.e., if the corresponding rohcProfile has a value of\n         0x0005.  If the corresponding rohcProfile has a value\n         other than 0x0005, then this object MUST NOT be\n         instantiated.')
rohcRtpPacketSizeUsed = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 2, 1, 5), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpPacketSizeUsed.setDescription('This object is only applicable to compressor contexts\n         using the UDP, RTP, or ESP profile.  When retrieved,\n         it will have the value true(1) if the packet size is\n         used.  Otherwise, its value will be false(2).\n\n         The value of this object is only valid for UDP, RTP,\n         and ESP profiles, i.e., if the corresponding rohcProfile\n         has a value of either 0x0001, 0x0002 or 0x0003.  If\n         the corresponding rohcProfile has a value other than\n         0x0001, 0x0002 or 0x0003, then this object MUST NOT be\n         instantiated.')
rohcRtpPacketSizeRestrictedType = MibTableColumn((1, 3, 6, 1, 2, 1, 114, 1, 2, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("nhpOnly", 1), ("rhpOnly", 2), ("noRestrictions", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rohcRtpPacketSizeRestrictedType.setDescription('This object is only applicable to preferred packet\n\n         sizes of compressor contexts using the LLA profile.\n         When retrieved, it will indicate whether the packet\n         size is preferred for NHP only, for RHP only, or\n         for both of them.\n\n         The value of this object is only valid for LLA profiles,\n         i.e., if the corresponding rohcProfile has a value of\n         0x0005.  If the corresponding rohcProfile has a value\n         other than 0x0005, then this object MUST NOT be\n         instantiated.')
rohcRtpCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 114, 2, 1))
rohcRtpGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 114, 2, 2))
rohcRtpCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 114, 2, 1, 1)).setObjects(*(("ROHC-RTP-MIB", "rohcRtpContextGroup"), ("ROHC-RTP-MIB", "rohcRtpPacketSizesGroup"), ("ROHC-RTP-MIB", "rohcRtpStatisticsGroup"),))
if mibBuilder.loadTexts: rohcRtpCompliance.setDescription('The compliance statement for SNMP entities that implement\n         the ROHC-RTP-MIB.\n\n         Note that compliance with this compliance\n         statement requires compliance with the\n         rohcCompliance MODULE-COMPLIANCE statement of the\n         ROHC-MIB and with the ifCompliance3 MODULE-COMPLIANCE\n         statement of the IF-MIB (RFC2863).')
rohcRtpContextGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 114, 2, 2, 1)).setObjects(*(("ROHC-RTP-MIB", "rohcRtpContextState"), ("ROHC-RTP-MIB", "rohcRtpContextMode"), ("ROHC-RTP-MIB", "rohcRtpContextAlwaysPad"), ("ROHC-RTP-MIB", "rohcRtpContextLargePktsAllowed"), ("ROHC-RTP-MIB", "rohcRtpContextVerifyPeriod"),))
if mibBuilder.loadTexts: rohcRtpContextGroup.setDescription('A collection of objects providing information about\n         ROHC RTP compressors and decompressors.')
rohcRtpPacketSizesGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 114, 2, 2, 2)).setObjects(*(("ROHC-RTP-MIB", "rohcRtpContextSizesAllowed"), ("ROHC-RTP-MIB", "rohcRtpContextSizesUsed"), ("ROHC-RTP-MIB", "rohcRtpPacketSizePreferred"), ("ROHC-RTP-MIB", "rohcRtpPacketSizeUsed"), ("ROHC-RTP-MIB", "rohcRtpPacketSizeRestrictedType"),))
if mibBuilder.loadTexts: rohcRtpPacketSizesGroup.setDescription('A collection of objects providing information about\n         allowed and used packet sizes at a ROHC RTP compressor.')
rohcRtpStatisticsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 114, 2, 2, 3)).setObjects(*(("ROHC-RTP-MIB", "rohcRtpContextACKs"), ("ROHC-RTP-MIB", "rohcRtpContextNACKs"), ("ROHC-RTP-MIB", "rohcRtpContextSNACKs"), ("ROHC-RTP-MIB", "rohcRtpContextNHPs"), ("ROHC-RTP-MIB", "rohcRtpContextCSPs"), ("ROHC-RTP-MIB", "rohcRtpContextCCPs"), ("ROHC-RTP-MIB", "rohcRtpContextPktsLostPhysical"), ("ROHC-RTP-MIB", "rohcRtpContextPktsLostPreLink"),))
if mibBuilder.loadTexts: rohcRtpStatisticsGroup.setDescription('A collection of objects providing ROHC compressor and\n         decompressor statistics.')
mibBuilder.exportSymbols("ROHC-RTP-MIB", rohcRtpPacketSizeTable=rohcRtpPacketSizeTable, rohcRtpPacketSizesGroup=rohcRtpPacketSizesGroup, rohcRtpContextCSPs=rohcRtpContextCSPs, rohcRtpPacketSize=rohcRtpPacketSize, rohcRtpObjects=rohcRtpObjects, rohcRtpCompliances=rohcRtpCompliances, rohcRtpContextGroup=rohcRtpContextGroup, rohcRtpContextNHPs=rohcRtpContextNHPs, rohcRtpContextAlwaysPad=rohcRtpContextAlwaysPad, rohcRtpPacketSizeRestrictedType=rohcRtpPacketSizeRestrictedType, rohcRtpContextPktsLostPreLink=rohcRtpContextPktsLostPreLink, rohcRtpContextVerifyPeriod=rohcRtpContextVerifyPeriod, rohcRtpContextCCPs=rohcRtpContextCCPs, rohcRtpContextACKs=rohcRtpContextACKs, PYSNMP_MODULE_ID=rohcRtpMIB, rohcRtpCompliance=rohcRtpCompliance, rohcRtpContextSNACKs=rohcRtpContextSNACKs, rohcRtpPacketSizeEntry=rohcRtpPacketSizeEntry, rohcRtpConformance=rohcRtpConformance, rohcRtpMIB=rohcRtpMIB, rohcRtpContextMode=rohcRtpContextMode, rohcRtpContextSizesAllowed=rohcRtpContextSizesAllowed, rohcRtpContextEntry=rohcRtpContextEntry, rohcRtpPacketSizeUsed=rohcRtpPacketSizeUsed, rohcRtpContextSizesUsed=rohcRtpContextSizesUsed, rohcRtpContextPktsLostPhysical=rohcRtpContextPktsLostPhysical, rohcRtpStatisticsGroup=rohcRtpStatisticsGroup, rohcRtpContextLargePktsAllowed=rohcRtpContextLargePktsAllowed, rohcRtpContextState=rohcRtpContextState, rohcRtpGroups=rohcRtpGroups, rohcRtpContextTable=rohcRtpContextTable, rohcRtpContextNACKs=rohcRtpContextNACKs, rohcRtpPacketSizePreferred=rohcRtpPacketSizePreferred)



#
# PySNMP MIB module MTA-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/MTA-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:22:19 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, SingleValueConstraint, ConstraintsUnion, ValueRangeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsUnion", "ValueRangeConstraint", "ConstraintsIntersection")
( URLString, applIndex, ) = mibBuilder.importSymbols("NETWORK-SERVICES-MIB", "URLString", "applIndex")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( iso, Integer32, Unsigned32, Bits, ObjectIdentity, Gauge32, Counter32, MibScalar, MibTable, MibTableRow, MibTableColumn, TimeTicks, IpAddress, MibIdentifier, Counter64, NotificationType, mib_2, ModuleIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "iso", "Integer32", "Unsigned32", "Bits", "ObjectIdentity", "Gauge32", "Counter32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "TimeTicks", "IpAddress", "MibIdentifier", "Counter64", "NotificationType", "mib-2", "ModuleIdentity")
( DisplayString, TimeInterval, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TimeInterval", "TextualConvention")
mta = ModuleIdentity((1, 3, 6, 1, 2, 1, 28)).setRevisions(("2000-03-03 00:00", "1999-05-12 00:00", "1997-08-17 00:00", "1993-11-28 00:00",))
if mibBuilder.loadTexts: mta.setLastUpdated('200003030000Z')
if mibBuilder.loadTexts: mta.setOrganization('IETF Mail and Directory Management Working Group')
if mibBuilder.loadTexts: mta.setContactInfo('        Ned Freed\n\n         Postal: Innosoft International, Inc.\n                 1050 Lakes Drive\n                 West Covina, CA 91790\n                 US\n\n         Tel: +1 626 919 3600\n         Fax: +1 626 919 3614\n\n         E-Mail: ned.freed@innosoft.com')
if mibBuilder.loadTexts: mta.setDescription('The MIB module describing Message Transfer Agents (MTAs)')
mtaTable = MibTable((1, 3, 6, 1, 2, 1, 28, 1), )
if mibBuilder.loadTexts: mtaTable.setDescription('The table holding information specific to an MTA.')
mtaEntry = MibTableRow((1, 3, 6, 1, 2, 1, 28, 1, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"))
if mibBuilder.loadTexts: mtaEntry.setDescription('The entry associated with each MTA.')
mtaReceivedMessages = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 1, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaReceivedMessages.setDescription('The number of messages received since MTA initialization.\n         This includes messages transmitted to this MTA from other\n         MTAs as well as messages that have been submitted to the\n         MTA directly by end-users or applications.')
mtaStoredMessages = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 1, 1, 2), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaStoredMessages.setDescription('The total number of messages currently stored in the MTA.\n         This includes messages that are awaiting transmission to\n         some other MTA or are waiting for delivery to an end-user\n         or application.')
mtaTransmittedMessages = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaTransmittedMessages.setDescription('The number of messages transmitted since MTA initialization.\n         This includes messages that were transmitted to some other\n         MTA or are waiting for delivery to an end-user or\n         application.')
mtaReceivedVolume = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 1, 1, 4), Counter32()).setUnits('K-octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaReceivedVolume.setDescription('The total volume of messages received since MTA\n         initialization, measured in kilo-octets.  This volume should\n         include all transferred data that is logically above the mail\n         transport protocol level.  For example, an SMTP-based MTA\n         should use the number of kilo-octets in the message header\n         and body, while an X.400-based MTA should use the number of\n         kilo-octets of P2 data.  This includes messages transmitted\n         to this MTA from other MTAs as well as messages that have\n         been submitted to the MTA directly by end-users or\n         applications.')
mtaStoredVolume = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 1, 1, 5), Gauge32()).setUnits('K-octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaStoredVolume.setDescription('The total volume of messages currently stored in the MTA,\n         measured in kilo-octets.  This volume should include all\n         stored data that is logically above the mail transport\n         protocol level.  For example, an SMTP-based MTA should\n         use the number of kilo-octets in the message header and\n         body, while an X.400-based MTA would use the number of\n         kilo-octets of P2 data.  This includes messages that are\n         awaiting transmission to some other MTA or are waiting\n         for delivery to an end-user or application.')
mtaTransmittedVolume = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 1, 1, 6), Counter32()).setUnits('K-octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaTransmittedVolume.setDescription('The total volume of messages transmitted since MTA\n         initialization, measured in kilo-octets.  This volume should\n         include all transferred data that is logically above the mail\n         transport protocol level.  For example, an SMTP-based MTA\n         should use the number of kilo-octets in the message header\n         and body, while an X.400-based MTA should use the number of\n         kilo-octets of P2 data.  This includes messages that were\n         transmitted to some other MTA or are waiting for delivery\n         to an end-user or application.')
mtaReceivedRecipients = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaReceivedRecipients.setDescription('The total number of recipients specified in all messages\n         received since MTA initialization.  Recipients this MTA\n         has no responsibility for, i.e. inactive envelope\n         recipients or ones referred to in message headers,\n         should not be counted even if information about such\n         recipients is available.  This includes messages\n         transmitted to this MTA from other MTAs as well as\n         messages that have been submitted to the MTA directly\n         by end-users or applications.')
mtaStoredRecipients = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 1, 1, 8), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaStoredRecipients.setDescription('The total number of recipients specified in all messages\n         currently stored in the MTA.  Recipients this MTA has no\n         responsibility for, i.e. inactive envelope recipients or\n         ones referred to in message headers, should not be\n         counted.  This includes messages that are awaiting\n         transmission to some other MTA or are waiting for\n         delivery to an end-user or application.')
mtaTransmittedRecipients = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 1, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaTransmittedRecipients.setDescription('The total number of recipients specified in all messages\n         transmitted since MTA initialization.  Recipients this\n         MTA had no responsibility for, i.e. inactive envelope\n         recipients or ones referred to in message headers,\n         should not be counted.  This includes messages that were\n         transmitted to some other MTA or are waiting for\n         delivery to an end-user or application.')
mtaSuccessfulConvertedMessages = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 1, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaSuccessfulConvertedMessages.setDescription('The number of messages that have been successfully\n         converted from one form to another since MTA\n         initialization.')
mtaFailedConvertedMessages = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 1, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaFailedConvertedMessages.setDescription('The number of messages for which an unsuccessful\n         attempt was made to convert them from one form to\n         another since MTA initialization.')
mtaLoopsDetected = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 1, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaLoopsDetected.setDescription("A message loop is defined as a situation where the MTA\n         decides that a given message will never be delivered to\n         one or more recipients and instead will continue to\n         loop endlessly through one or more MTAs.  This variable\n         counts the number of times the MTA has detected such a\n         situation since MTA initialization. Note that the\n         mechanism MTAs use to detect loops (e.g., trace field\n         counting, count of references to this MTA in a trace\n         field, examination of DNS or other directory information,\n         etc.), the level at which loops are detected (e.g., per\n         message, per recipient, per directory entry, etc.), and\n         the handling of a loop once it is detected (e.g., looping\n         messages are held, looping messages are bounced or sent\n         to the postmaster, messages that the MTA knows will loop\n         won't be accepted, etc.) vary widely from one MTA to the\n         next and cannot be inferred from this variable.")
mtaGroupTable = MibTable((1, 3, 6, 1, 2, 1, 28, 2), )
if mibBuilder.loadTexts: mtaGroupTable.setDescription('The table holding information specific to each MTA group.')
mtaGroupEntry = MibTableRow((1, 3, 6, 1, 2, 1, 28, 2, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"), (0, "MTA-MIB", "mtaGroupIndex"))
if mibBuilder.loadTexts: mtaGroupEntry.setDescription('The entry associated with each MTA group.')
mtaGroupIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: mtaGroupIndex.setDescription('The index associated with a group for a given MTA.')
mtaGroupReceivedMessages = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupReceivedMessages.setDescription('The number of messages received to this group since\n         group creation.')
mtaGroupRejectedMessages = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupRejectedMessages.setDescription('The number of messages rejected by this group since\n         group creation.')
mtaGroupStoredMessages = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 4), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupStoredMessages.setDescription("The total number of messages currently stored in this\n         group's queue.")
mtaGroupTransmittedMessages = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupTransmittedMessages.setDescription('The number of messages transmitted by this group since\n         group creation.')
mtaGroupReceivedVolume = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 6), Counter32()).setUnits('K-octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupReceivedVolume.setDescription('The total volume of messages received to this group since\n         group creation, measured in kilo-octets.  This volume\n         should include all transferred data that is logically above\n         the mail transport protocol level.  For example, an\n         SMTP-based MTA should use the number of kilo-octets in the\n         message header and body, while an X.400-based MTA should use\n         the number of kilo-octets of P2 data.')
mtaGroupStoredVolume = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 7), Gauge32()).setUnits('K-octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupStoredVolume.setDescription("The total volume of messages currently stored in this\n         group's queue, measured in kilo-octets.  This volume should\n         include all stored data that is logically above the mail\n         transport protocol level.  For example, an SMTP-based\n         MTA should use the number of kilo-octets in the message\n         header and body, while an X.400-based MTA would use the\n         number of kilo-octets of P2 data.")
mtaGroupTransmittedVolume = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 8), Counter32()).setUnits('K-octets').setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupTransmittedVolume.setDescription('The total volume of messages transmitted by this group\n         since group creation, measured in kilo-octets.  This\n         volume should include all transferred data that is logically\n         above the mail transport protocol level.  For example, an\n         SMTP-based MTA should use the number of kilo-octets in the\n         message header and body, while an X.400-based MTA should use\n         the number of kilo-octets of P2 data.')
mtaGroupReceivedRecipients = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupReceivedRecipients.setDescription('The total number of recipients specified in all messages\n         received to this group since group creation.\n         Recipients this MTA has no responsibility for should not\n         be counted.')
mtaGroupStoredRecipients = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 10), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupStoredRecipients.setDescription("The total number of recipients specified in all messages\n         currently stored in this group's queue.  Recipients this\n         MTA has no responsibility for should not be counted.")
mtaGroupTransmittedRecipients = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupTransmittedRecipients.setDescription('The total number of recipients specified in all messages\n         transmitted by this group since group creation.\n         Recipients this MTA had no responsibility for should not\n         be counted.')
mtaGroupOldestMessageStored = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 12), TimeInterval()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupOldestMessageStored.setDescription("Time since the oldest message in this group's queue was\n         placed in the queue.")
mtaGroupInboundAssociations = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 13), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupInboundAssociations.setDescription('The number of current associations to the group, where the\n         group is the responder.')
mtaGroupOutboundAssociations = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 14), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupOutboundAssociations.setDescription('The number of current associations to the group, where the\n        group is the initiator.')
mtaGroupAccumulatedInboundAssociations = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupAccumulatedInboundAssociations.setDescription('The total number of associations to the group since\n        group creation, where the MTA was the responder.')
mtaGroupAccumulatedOutboundAssociations = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupAccumulatedOutboundAssociations.setDescription('The total number of associations from the group since\n         group creation, where the MTA was the initiator.')
mtaGroupLastInboundActivity = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 17), TimeInterval()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupLastInboundActivity.setDescription('Time since the last time that this group had an active\n        inbound association for purposes of message reception.')
mtaGroupLastOutboundActivity = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 18), TimeInterval()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupLastOutboundActivity.setDescription('Time since the last time that this group had a\n         successful outbound association for purposes of\n         message delivery.')
mtaGroupLastOutboundAssociationAttempt = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 34), TimeInterval()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupLastOutboundAssociationAttempt.setDescription('Time since the last time that this group attempted\n         to make an outbound association for purposes of\n         message delivery.')
mtaGroupRejectedInboundAssociations = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupRejectedInboundAssociations.setDescription('The total number of inbound associations the group has\n        rejected, since group creation.  Rejected associations\n        are not counted in the accumulated association totals.')
mtaGroupFailedOutboundAssociations = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 20), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupFailedOutboundAssociations.setDescription('The total number associations where the group was the\n        initiator and association establishment has failed,\n        since group creation.  Failed associations are\n        not counted in the accumulated association totals.')
mtaGroupInboundRejectionReason = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 21), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupInboundRejectionReason.setDescription("The failure reason, if any, for the last association this\n        group refused to respond to. If no association attempt\n        has been made since the MTA was initialized the value\n        should be 'never'.")
mtaGroupOutboundConnectFailureReason = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 22), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupOutboundConnectFailureReason.setDescription("The failure reason, if any, for the last association attempt\n        this group initiated. If no association attempt has been\n        made since the MTA was initialized the value should be\n        'never'.")
mtaGroupScheduledRetry = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 23), TimeInterval()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupScheduledRetry.setDescription('The amount of time until this group is next scheduled to\n         attempt to make an association.')
mtaGroupMailProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 24), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupMailProtocol.setDescription("An identification of the protocol being used by this group.\n         For an group employing OSI protocols, this will be the\n         Application Context.    For Internet applications, OID\n         values of the form {applTCPProtoID port} or {applUDPProtoID\n         port} are used for TCP-based and UDP-based protocols,\n         respectively. In either case 'port' corresponds to the\n         primary port number being used by the protocol. The\n         usual IANA procedures may be used to register ports for\n         new protocols. applTCPProtoID and applUDPProtoID are\n         defined in the NETWORK-SERVICES-MIB, RFC 2788.")
mtaGroupName = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 25), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupName.setDescription("A descriptive name for the group. If this group connects to\n         a single remote MTA this should be the name of that MTA. If\n         this in turn is an Internet MTA this should be the domain\n         name.  For an OSI MTA it should be the string encoded\n         distinguished name of the managed object using the format\n         defined in RFC 2253.  For X.400(1984) MTAs which do not\n         have a Distinguished Name, the RFC 2156 syntax\n         'mta in globalid' used in X400-Received: fields can be\n         used.")
mtaGroupSuccessfulConvertedMessages = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 26), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupSuccessfulConvertedMessages.setDescription('The number of messages that have been successfully\n         converted from one form to another in this group\n         since group creation.')
mtaGroupFailedConvertedMessages = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 27), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupFailedConvertedMessages.setDescription('The number of messages for which an unsuccessful\n         attempt was made to convert them from one form to\n         another in this group since group creation.')
mtaGroupDescription = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 28), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupDescription.setDescription("A description of the group's purpose.  This information is\n         intended to identify the group in a status display.")
mtaGroupURL = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 29), URLString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupURL.setDescription('A URL pointing to a description of the group.  This\n         information is intended to identify and briefly describe\n         the group in a status display.')
mtaGroupCreationTime = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 30), TimeInterval()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupCreationTime.setDescription('Time since this group was first created.')
mtaGroupHierarchy = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 31), Integer32().subtype(subtypeSpec=ValueRangeConstraint(-2147483648,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupHierarchy.setDescription("Describes how this group fits into the hierarchy. A\n         positive value is interpreted as an mtaGroupIndex\n         value for some other group whose variables include\n         those of this group (and usually others). A negative\n         value is interpreted as a group collection code: Groups\n         with common negative hierarchy values comprise one\n         particular breakdown of MTA activity as a whole. A\n         zero value means that this MIB implementation doesn't\n         implement hierarchy indicators and thus the overall\n         group hierarchy cannot be determined.")
mtaGroupOldestMessageId = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 32), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupOldestMessageId.setDescription("Message ID of the oldest message in the group's queue.\n         Whenever possible this should be in the form of an\n         RFC 822 msg-id; X.400 may convert X.400 message\n         identifiers to this form by following the rules laid\n         out in RFC2156.")
mtaGroupLoopsDetected = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 2, 1, 33), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupLoopsDetected.setDescription("A message loop is defined as a situation where the MTA\n         decides that a given message will never be delivered to\n         one or more recipients and instead will continue to\n         loop endlessly through one or more MTAs.  This variable\n         counts the number of times the MTA has detected such a\n         situation in conjunction with something associated with\n         this group since group creation.  Note that the\n         mechanism MTAs use to detect loops (e.g., trace field\n         counting, count of references to this MTA in a trace\n         field, examination of DNS or other directory information,\n         etc.), the level at which loops are detected (e.g., per\n         message, per recipient, per directory entry, etc.), and\n         the handling of a loop once it is detected (e.g., looping\n         messages are held, looping messages are bounced or sent\n         to the postmaster, messages that the MTA knows will loop\n         won't be accepted, etc.) vary widely from one MTA to the\n         next and cannot be inferred from this variable.")
mtaGroupAssociationTable = MibTable((1, 3, 6, 1, 2, 1, 28, 3), )
if mibBuilder.loadTexts: mtaGroupAssociationTable.setDescription('The table holding information regarding the associations\n         for each MTA group.')
mtaGroupAssociationEntry = MibTableRow((1, 3, 6, 1, 2, 1, 28, 3, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"), (0, "MTA-MIB", "mtaGroupIndex"), (0, "MTA-MIB", "mtaGroupAssociationIndex"))
if mibBuilder.loadTexts: mtaGroupAssociationEntry.setDescription('The entry holding information regarding the associations\n         for each MTA group.')
mtaGroupAssociationIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupAssociationIndex.setDescription("Reference into association table to allow correlation of\n         this group's active associations with the association table.")
mtaGroupErrorTable = MibTable((1, 3, 6, 1, 2, 1, 28, 5), )
if mibBuilder.loadTexts: mtaGroupErrorTable.setDescription('The table holding information regarding accumulated errors\n         for each MTA group.')
mtaGroupErrorEntry = MibTableRow((1, 3, 6, 1, 2, 1, 28, 5, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"), (0, "MTA-MIB", "mtaGroupIndex"), (0, "MTA-MIB", "mtaStatusCode"))
if mibBuilder.loadTexts: mtaGroupErrorEntry.setDescription('The entry holding information regarding accumulated\n         errors for each MTA group.')
mtaGroupInboundErrorCount = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 5, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupInboundErrorCount.setDescription('Count of the number of errors of a given type that have\n         been accumulated in association with a particular group\n         while processing incoming messages. In the case of SMTP\n         these will typically be errors reporting by an SMTP\n         server to the remote client; in the case of X.400\n         these will typically be errors encountered while\n         processing an incoming message.')
mtaGroupInternalErrorCount = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 5, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupInternalErrorCount.setDescription('Count of the number of errors of a given type that have\n         been accumulated in association with a particular group\n         during internal MTA processing.')
mtaGroupOutboundErrorCount = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 5, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mtaGroupOutboundErrorCount.setDescription("Count of the number of errors of a given type that have\n         been accumulated in association with a particular group's\n         outbound connection activities. In the case of an SMTP\n         client these will typically be errors reported while\n         attempting to contact or while communicating with the\n         remote SMTP server. In the case of X.400 these will\n         typically be errors encountered while constructing\n         or attempting to deliver an outgoing message.")
mtaStatusCode = MibTableColumn((1, 3, 6, 1, 2, 1, 28, 5, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(4000000,5999999)))
if mibBuilder.loadTexts: mtaStatusCode.setDescription("An index capable of representing an Enhanced Mail System\n         Status Code.  Enhanced Mail System Status Codes are\n         defined in RFC 1893.  These codes have the form\n\n             class.subject.detail\n\n         Here 'class' is either 2, 4, or 5 and both 'subject' and\n         'detail'  are integers in the range 0..999. Given a status\n         code the corresponding index value is defined to be\n         ((class * 1000) + subject) * 1000 + detail.  Both SMTP\n         error response codes and X.400 reason and diagnostic codes\n         can be mapped into these codes, resulting in a namespace\n         capable of describing most error conditions a mail system\n         encounters in a generic yet detailed way.")
mtaConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 28, 4))
mtaGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 28, 4, 1))
mtaCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 28, 4, 2))
mtaCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 28, 4, 2, 1)).setObjects(*(("MTA-MIB", "mtaRFC1566Group"),))
if mibBuilder.loadTexts: mtaCompliance.setDescription('The compliance statement for RFC 1566 implementations\n         which support the Mail Monitoring MIB for basic\n         monitoring of MTAs.')
mtaAssocCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 28, 4, 2, 2)).setObjects(*(("MTA-MIB", "mtaRFC1566Group"), ("MTA-MIB", "mtaRFC1566AssocGroup"),))
if mibBuilder.loadTexts: mtaAssocCompliance.setDescription('The compliance statement for RFC 1566 implementations\n         which support the Mail Monitoring MIB for monitoring\n         of MTAs and their associations.')
mtaRFC2249Compliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 28, 4, 2, 5)).setObjects(*(("MTA-MIB", "mtaRFC2249Group"),))
if mibBuilder.loadTexts: mtaRFC2249Compliance.setDescription('The compliance statement for RFC 2249 implementations\n         which support the Mail Monitoring MIB for basic\n         monitoring of MTAs.')
mtaRFC2249AssocCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 28, 4, 2, 6)).setObjects(*(("MTA-MIB", "mtaRFC2249Group"), ("MTA-MIB", "mtaRFC2249AssocGroup"),))
if mibBuilder.loadTexts: mtaRFC2249AssocCompliance.setDescription('The compliance statement for RFC 2249 implementations\n         which support the Mail Monitoring MIB for monitoring of\n         MTAs and their associations.')
mtaRFC2249ErrorCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 28, 4, 2, 7)).setObjects(*(("MTA-MIB", "mtaRFC2249Group"), ("MTA-MIB", "mtaRFC2249ErrorGroup"),))
if mibBuilder.loadTexts: mtaRFC2249ErrorCompliance.setDescription('The compliance statement for RFC 2249 implementations\n         which support the Mail Monitoring MIB for monitoring of\n         MTAs and detailed errors.')
mtaRFC2249FullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 28, 4, 2, 8)).setObjects(*(("MTA-MIB", "mtaRFC2249Group"), ("MTA-MIB", "mtaRFC2249AssocGroup"), ("MTA-MIB", "mtaRFC2249ErrorGroup"),))
if mibBuilder.loadTexts: mtaRFC2249FullCompliance.setDescription('The compliance statement for RFC 2249 implementations\n         which support the full Mail Monitoring MIB for\n         monitoring of MTAs, associations, and detailed errors.')
mtaRFC2789Compliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 28, 4, 2, 9)).setObjects(*(("MTA-MIB", "mtaRFC2789Group"),))
if mibBuilder.loadTexts: mtaRFC2789Compliance.setDescription('The compliance statement for RFC 2789 implementations\n         which support the Mail Monitoring MIB for basic\n         monitoring of MTAs.')
mtaRFC2789AssocCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 28, 4, 2, 10)).setObjects(*(("MTA-MIB", "mtaRFC2789Group"), ("MTA-MIB", "mtaRFC2789AssocGroup"),))
if mibBuilder.loadTexts: mtaRFC2789AssocCompliance.setDescription('The compliance statement for RFC 2789 implementations\n         which support the Mail Monitoring MIB for monitoring of\n         MTAs and their associations.')
mtaRFC2789ErrorCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 28, 4, 2, 11)).setObjects(*(("MTA-MIB", "mtaRFC2789Group"), ("MTA-MIB", "mtaRFC2789ErrorGroup"),))
if mibBuilder.loadTexts: mtaRFC2789ErrorCompliance.setDescription('The compliance statement for RFC 2789 implementations\n         which support the Mail Monitoring MIB for monitoring of\n         MTAs and detailed errors.')
mtaRFC2789FullCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 28, 4, 2, 12)).setObjects(*(("MTA-MIB", "mtaRFC2789Group"), ("MTA-MIB", "mtaRFC2789AssocGroup"), ("MTA-MIB", "mtaRFC2789ErrorGroup"),))
if mibBuilder.loadTexts: mtaRFC2789FullCompliance.setDescription('The compliance statement for RFC 2789 implementations\n         which support the full Mail Monitoring MIB for\n         monitoring of MTAs, associations, and detailed errors.')
mtaRFC1566Group = ObjectGroup((1, 3, 6, 1, 2, 1, 28, 4, 1, 10)).setObjects(*(("MTA-MIB", "mtaReceivedMessages"), ("MTA-MIB", "mtaStoredMessages"), ("MTA-MIB", "mtaTransmittedMessages"), ("MTA-MIB", "mtaReceivedVolume"), ("MTA-MIB", "mtaStoredVolume"), ("MTA-MIB", "mtaTransmittedVolume"), ("MTA-MIB", "mtaReceivedRecipients"), ("MTA-MIB", "mtaStoredRecipients"), ("MTA-MIB", "mtaTransmittedRecipients"), ("MTA-MIB", "mtaGroupReceivedMessages"), ("MTA-MIB", "mtaGroupRejectedMessages"), ("MTA-MIB", "mtaGroupStoredMessages"), ("MTA-MIB", "mtaGroupTransmittedMessages"), ("MTA-MIB", "mtaGroupReceivedVolume"), ("MTA-MIB", "mtaGroupStoredVolume"), ("MTA-MIB", "mtaGroupTransmittedVolume"), ("MTA-MIB", "mtaGroupReceivedRecipients"), ("MTA-MIB", "mtaGroupStoredRecipients"), ("MTA-MIB", "mtaGroupTransmittedRecipients"), ("MTA-MIB", "mtaGroupOldestMessageStored"), ("MTA-MIB", "mtaGroupInboundAssociations"), ("MTA-MIB", "mtaGroupOutboundAssociations"), ("MTA-MIB", "mtaGroupAccumulatedInboundAssociations"), ("MTA-MIB", "mtaGroupAccumulatedOutboundAssociations"), ("MTA-MIB", "mtaGroupLastInboundActivity"), ("MTA-MIB", "mtaGroupLastOutboundActivity"), ("MTA-MIB", "mtaGroupRejectedInboundAssociations"), ("MTA-MIB", "mtaGroupFailedOutboundAssociations"), ("MTA-MIB", "mtaGroupInboundRejectionReason"), ("MTA-MIB", "mtaGroupOutboundConnectFailureReason"), ("MTA-MIB", "mtaGroupScheduledRetry"), ("MTA-MIB", "mtaGroupMailProtocol"), ("MTA-MIB", "mtaGroupName"),))
if mibBuilder.loadTexts: mtaRFC1566Group.setDescription('A collection of objects providing basic monitoring of MTAs.\n         This is the original set of such objects defined in RFC\n         1566.')
mtaRFC1566AssocGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 28, 4, 1, 11)).setObjects(*(("MTA-MIB", "mtaGroupAssociationIndex"),))
if mibBuilder.loadTexts: mtaRFC1566AssocGroup.setDescription('A collection of objects providing monitoring of MTA\n         associations.  This is the original set of such objects\n         defined in RFC 1566.')
mtaRFC2249Group = ObjectGroup((1, 3, 6, 1, 2, 1, 28, 4, 1, 4)).setObjects(*(("MTA-MIB", "mtaReceivedMessages"), ("MTA-MIB", "mtaStoredMessages"), ("MTA-MIB", "mtaTransmittedMessages"), ("MTA-MIB", "mtaReceivedVolume"), ("MTA-MIB", "mtaStoredVolume"), ("MTA-MIB", "mtaTransmittedVolume"), ("MTA-MIB", "mtaReceivedRecipients"), ("MTA-MIB", "mtaStoredRecipients"), ("MTA-MIB", "mtaTransmittedRecipients"), ("MTA-MIB", "mtaSuccessfulConvertedMessages"), ("MTA-MIB", "mtaFailedConvertedMessages"), ("MTA-MIB", "mtaGroupReceivedMessages"), ("MTA-MIB", "mtaGroupRejectedMessages"), ("MTA-MIB", "mtaGroupStoredMessages"), ("MTA-MIB", "mtaGroupTransmittedMessages"), ("MTA-MIB", "mtaGroupReceivedVolume"), ("MTA-MIB", "mtaGroupStoredVolume"), ("MTA-MIB", "mtaGroupTransmittedVolume"), ("MTA-MIB", "mtaGroupReceivedRecipients"), ("MTA-MIB", "mtaGroupStoredRecipients"), ("MTA-MIB", "mtaGroupTransmittedRecipients"), ("MTA-MIB", "mtaGroupOldestMessageStored"), ("MTA-MIB", "mtaGroupInboundAssociations"), ("MTA-MIB", "mtaGroupOutboundAssociations"), ("MTA-MIB", "mtaLoopsDetected"), ("MTA-MIB", "mtaGroupAccumulatedInboundAssociations"), ("MTA-MIB", "mtaGroupAccumulatedOutboundAssociations"), ("MTA-MIB", "mtaGroupLastInboundActivity"), ("MTA-MIB", "mtaGroupLastOutboundActivity"), ("MTA-MIB", "mtaGroupLastOutboundAssociationAttempt"), ("MTA-MIB", "mtaGroupRejectedInboundAssociations"), ("MTA-MIB", "mtaGroupFailedOutboundAssociations"), ("MTA-MIB", "mtaGroupInboundRejectionReason"), ("MTA-MIB", "mtaGroupOutboundConnectFailureReason"), ("MTA-MIB", "mtaGroupScheduledRetry"), ("MTA-MIB", "mtaGroupMailProtocol"), ("MTA-MIB", "mtaGroupName"), ("MTA-MIB", "mtaGroupSuccessfulConvertedMessages"), ("MTA-MIB", "mtaGroupFailedConvertedMessages"), ("MTA-MIB", "mtaGroupDescription"), ("MTA-MIB", "mtaGroupURL"), ("MTA-MIB", "mtaGroupCreationTime"), ("MTA-MIB", "mtaGroupHierarchy"), ("MTA-MIB", "mtaGroupOldestMessageId"), ("MTA-MIB", "mtaGroupLoopsDetected"),))
if mibBuilder.loadTexts: mtaRFC2249Group.setDescription('A collection of objects providing basic monitoring of MTAs.\n         This group was originally defined in RFC 2249.')
mtaRFC2249AssocGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 28, 4, 1, 5)).setObjects(*(("MTA-MIB", "mtaGroupAssociationIndex"),))
if mibBuilder.loadTexts: mtaRFC2249AssocGroup.setDescription('A collection of objects providing monitoring of MTA\n         associations.  This group was originally defined in RFC\n         2249.')
mtaRFC2249ErrorGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 28, 4, 1, 6)).setObjects(*(("MTA-MIB", "mtaGroupInboundErrorCount"), ("MTA-MIB", "mtaGroupInternalErrorCount"), ("MTA-MIB", "mtaGroupOutboundErrorCount"),))
if mibBuilder.loadTexts: mtaRFC2249ErrorGroup.setDescription('A collection of objects providing monitoring of\n         detailed MTA errors.  This group was originally defined\n         in RFC 2249.')
mtaRFC2789Group = ObjectGroup((1, 3, 6, 1, 2, 1, 28, 4, 1, 7)).setObjects(*(("MTA-MIB", "mtaReceivedMessages"), ("MTA-MIB", "mtaStoredMessages"), ("MTA-MIB", "mtaTransmittedMessages"), ("MTA-MIB", "mtaReceivedVolume"), ("MTA-MIB", "mtaStoredVolume"), ("MTA-MIB", "mtaTransmittedVolume"), ("MTA-MIB", "mtaReceivedRecipients"), ("MTA-MIB", "mtaStoredRecipients"), ("MTA-MIB", "mtaTransmittedRecipients"), ("MTA-MIB", "mtaSuccessfulConvertedMessages"), ("MTA-MIB", "mtaFailedConvertedMessages"), ("MTA-MIB", "mtaGroupReceivedMessages"), ("MTA-MIB", "mtaGroupRejectedMessages"), ("MTA-MIB", "mtaGroupStoredMessages"), ("MTA-MIB", "mtaGroupTransmittedMessages"), ("MTA-MIB", "mtaGroupReceivedVolume"), ("MTA-MIB", "mtaGroupStoredVolume"), ("MTA-MIB", "mtaGroupTransmittedVolume"), ("MTA-MIB", "mtaGroupReceivedRecipients"), ("MTA-MIB", "mtaGroupStoredRecipients"), ("MTA-MIB", "mtaGroupTransmittedRecipients"), ("MTA-MIB", "mtaGroupOldestMessageStored"), ("MTA-MIB", "mtaGroupInboundAssociations"), ("MTA-MIB", "mtaGroupOutboundAssociations"), ("MTA-MIB", "mtaLoopsDetected"), ("MTA-MIB", "mtaGroupAccumulatedInboundAssociations"), ("MTA-MIB", "mtaGroupAccumulatedOutboundAssociations"), ("MTA-MIB", "mtaGroupLastInboundActivity"), ("MTA-MIB", "mtaGroupLastOutboundActivity"), ("MTA-MIB", "mtaGroupLastOutboundAssociationAttempt"), ("MTA-MIB", "mtaGroupRejectedInboundAssociations"), ("MTA-MIB", "mtaGroupFailedOutboundAssociations"), ("MTA-MIB", "mtaGroupInboundRejectionReason"), ("MTA-MIB", "mtaGroupOutboundConnectFailureReason"), ("MTA-MIB", "mtaGroupScheduledRetry"), ("MTA-MIB", "mtaGroupMailProtocol"), ("MTA-MIB", "mtaGroupName"), ("MTA-MIB", "mtaGroupSuccessfulConvertedMessages"), ("MTA-MIB", "mtaGroupFailedConvertedMessages"), ("MTA-MIB", "mtaGroupDescription"), ("MTA-MIB", "mtaGroupURL"), ("MTA-MIB", "mtaGroupCreationTime"), ("MTA-MIB", "mtaGroupHierarchy"), ("MTA-MIB", "mtaGroupOldestMessageId"), ("MTA-MIB", "mtaGroupLoopsDetected"),))
if mibBuilder.loadTexts: mtaRFC2789Group.setDescription('A collection of objects providing basic monitoring of MTAs.\n         This is the appropriate group for RFC 2789.')
mtaRFC2789AssocGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 28, 4, 1, 8)).setObjects(*(("MTA-MIB", "mtaGroupAssociationIndex"),))
if mibBuilder.loadTexts: mtaRFC2789AssocGroup.setDescription('A collection of objects providing monitoring of MTA\n         associations.  This is the appropriate group for RFC\n         2789 association monitoring.')
mtaRFC2789ErrorGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 28, 4, 1, 9)).setObjects(*(("MTA-MIB", "mtaGroupInboundErrorCount"), ("MTA-MIB", "mtaGroupInternalErrorCount"), ("MTA-MIB", "mtaGroupOutboundErrorCount"),))
if mibBuilder.loadTexts: mtaRFC2789ErrorGroup.setDescription('A collection of objects providing monitoring of\n         detailed MTA errors.  This is the appropriate group\n         for RFC 2789 error monitoring.')
mibBuilder.exportSymbols("MTA-MIB", mtaReceivedRecipients=mtaReceivedRecipients, mtaGroupTransmittedVolume=mtaGroupTransmittedVolume, mtaRFC2249ErrorGroup=mtaRFC2249ErrorGroup, mtaGroupMailProtocol=mtaGroupMailProtocol, mtaFailedConvertedMessages=mtaFailedConvertedMessages, mtaGroupLastInboundActivity=mtaGroupLastInboundActivity, mtaGroupFailedConvertedMessages=mtaGroupFailedConvertedMessages, mtaGroupInboundErrorCount=mtaGroupInboundErrorCount, mtaSuccessfulConvertedMessages=mtaSuccessfulConvertedMessages, mtaGroupURL=mtaGroupURL, mtaRFC2789Group=mtaRFC2789Group, mtaGroupStoredVolume=mtaGroupStoredVolume, mtaGroupStoredMessages=mtaGroupStoredMessages, mtaGroupReceivedVolume=mtaGroupReceivedVolume, mtaGroupIndex=mtaGroupIndex, mtaGroupErrorEntry=mtaGroupErrorEntry, mtaGroupEntry=mtaGroupEntry, mtaRFC2789FullCompliance=mtaRFC2789FullCompliance, mtaCompliances=mtaCompliances, mtaGroupLastOutboundAssociationAttempt=mtaGroupLastOutboundAssociationAttempt, mtaGroupReceivedRecipients=mtaGroupReceivedRecipients, mtaGroupAccumulatedOutboundAssociations=mtaGroupAccumulatedOutboundAssociations, mtaGroupDescription=mtaGroupDescription, mtaGroupCreationTime=mtaGroupCreationTime, mtaGroupAssociationIndex=mtaGroupAssociationIndex, mtaRFC2789ErrorCompliance=mtaRFC2789ErrorCompliance, mtaGroupInternalErrorCount=mtaGroupInternalErrorCount, mtaTransmittedRecipients=mtaTransmittedRecipients, mtaGroupErrorTable=mtaGroupErrorTable, mtaGroups=mtaGroups, mtaRFC2249AssocGroup=mtaRFC2249AssocGroup, PYSNMP_MODULE_ID=mta, mtaGroupOutboundAssociations=mtaGroupOutboundAssociations, mtaGroupLastOutboundActivity=mtaGroupLastOutboundActivity, mtaGroupAssociationEntry=mtaGroupAssociationEntry, mta=mta, mtaStoredVolume=mtaStoredVolume, mtaConformance=mtaConformance, mtaRFC2789Compliance=mtaRFC2789Compliance, mtaGroupOutboundConnectFailureReason=mtaGroupOutboundConnectFailureReason, mtaStoredRecipients=mtaStoredRecipients, mtaGroupStoredRecipients=mtaGroupStoredRecipients, mtaGroupRejectedInboundAssociations=mtaGroupRejectedInboundAssociations, mtaGroupScheduledRetry=mtaGroupScheduledRetry, mtaRFC2249Compliance=mtaRFC2249Compliance, mtaGroupOldestMessageId=mtaGroupOldestMessageId, mtaRFC2789ErrorGroup=mtaRFC2789ErrorGroup, mtaGroupInboundAssociations=mtaGroupInboundAssociations, mtaGroupHierarchy=mtaGroupHierarchy, mtaLoopsDetected=mtaLoopsDetected, mtaReceivedMessages=mtaReceivedMessages, mtaStatusCode=mtaStatusCode, mtaTransmittedVolume=mtaTransmittedVolume, mtaGroupAssociationTable=mtaGroupAssociationTable, mtaRFC2249FullCompliance=mtaRFC2249FullCompliance, mtaTable=mtaTable, mtaGroupRejectedMessages=mtaGroupRejectedMessages, mtaGroupTransmittedMessages=mtaGroupTransmittedMessages, mtaRFC2249AssocCompliance=mtaRFC2249AssocCompliance, mtaGroupLoopsDetected=mtaGroupLoopsDetected, mtaGroupFailedOutboundAssociations=mtaGroupFailedOutboundAssociations, mtaGroupName=mtaGroupName, mtaRFC2789AssocGroup=mtaRFC2789AssocGroup, mtaAssocCompliance=mtaAssocCompliance, mtaGroupInboundRejectionReason=mtaGroupInboundRejectionReason, mtaRFC2249Group=mtaRFC2249Group, mtaReceivedVolume=mtaReceivedVolume, mtaGroupOldestMessageStored=mtaGroupOldestMessageStored, mtaStoredMessages=mtaStoredMessages, mtaGroupOutboundErrorCount=mtaGroupOutboundErrorCount, mtaEntry=mtaEntry, mtaGroupReceivedMessages=mtaGroupReceivedMessages, mtaRFC2249ErrorCompliance=mtaRFC2249ErrorCompliance, mtaRFC2789AssocCompliance=mtaRFC2789AssocCompliance, mtaGroupTransmittedRecipients=mtaGroupTransmittedRecipients, mtaGroupSuccessfulConvertedMessages=mtaGroupSuccessfulConvertedMessages, mtaGroupAccumulatedInboundAssociations=mtaGroupAccumulatedInboundAssociations, mtaRFC1566Group=mtaRFC1566Group, mtaRFC1566AssocGroup=mtaRFC1566AssocGroup, mtaTransmittedMessages=mtaTransmittedMessages, mtaGroupTable=mtaGroupTable, mtaCompliance=mtaCompliance)



#
# PySNMP MIB module ENTITY-SENSOR-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ENTITY-SENSOR-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:11:46 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ConstraintsUnion, SingleValueConstraint, ValueRangeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsUnion", "SingleValueConstraint", "ValueRangeConstraint", "ConstraintsIntersection")
( entityPhysicalGroup, entPhysicalIndex, ) = mibBuilder.importSymbols("ENTITY-MIB", "entityPhysicalGroup", "entPhysicalIndex")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( ModuleIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, IpAddress, mib_2, iso, TimeTicks, Bits, Counter64, Integer32, Counter32, ObjectIdentity, MibIdentifier, Gauge32, NotificationType, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ModuleIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "IpAddress", "mib-2", "iso", "TimeTicks", "Bits", "Counter64", "Integer32", "Counter32", "ObjectIdentity", "MibIdentifier", "Gauge32", "NotificationType")
( TextualConvention, DisplayString, TimeStamp, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString", "TimeStamp")
entitySensorMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 99)).setRevisions(("2002-12-16 00:00",))
if mibBuilder.loadTexts: entitySensorMIB.setLastUpdated('200212160000Z')
if mibBuilder.loadTexts: entitySensorMIB.setOrganization('IETF Entity MIB Working Group')
if mibBuilder.loadTexts: entitySensorMIB.setContactInfo('        Andy Bierman\n                     Cisco Systems, Inc.\n                Tel: +1 408-527-3711\n             E-mail: abierman@cisco.com\n             Postal: 170 West Tasman Drive\n                     San Jose, CA USA 95134\n\n                     Dan Romascanu\n                     Avaya Inc.\n                Tel: +972-3-645-8414\n              Email: dromasca@avaya.com\n             Postal: Atidim technology Park, Bldg. #3\n                     Tel Aviv, Israel, 61131\n\n                     K.C. Norseth\n                     L-3 Communications\n                Tel: +1 801-594-2809\n              Email: kenyon.c.norseth@L-3com.com\n             Postal: 640 N. 2200 West.\n\n                     Salt Lake City, Utah 84116-0850\n\n             Send comments to <entmib@ietf.org>\n             Mailing list subscription info:\n               http://www.ietf.org/mailman/listinfo/entmib ')
if mibBuilder.loadTexts: entitySensorMIB.setDescription('This module defines Entity MIB extensions for physical\n             sensors.\n\n             Copyright (C) The Internet Society (2002). This version\n             of this MIB module is part of RFC 3433; see the RFC\n             itself for full legal notices.')
entitySensorObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 99, 1))
entitySensorConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 99, 3))
class EntitySensorDataType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,))
    namedValues = NamedValues(("other", 1), ("unknown", 2), ("voltsAC", 3), ("voltsDC", 4), ("amperes", 5), ("watts", 6), ("hertz", 7), ("celsius", 8), ("percentRH", 9), ("rpm", 10), ("cmm", 11), ("truthvalue", 12),)

class EntitySensorDataScale(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17,))
    namedValues = NamedValues(("yocto", 1), ("zepto", 2), ("atto", 3), ("femto", 4), ("pico", 5), ("nano", 6), ("micro", 7), ("milli", 8), ("units", 9), ("kilo", 10), ("mega", 11), ("giga", 12), ("tera", 13), ("exa", 14), ("peta", 15), ("zetta", 16), ("yotta", 17),)

class EntitySensorPrecision(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(-8,9)

class EntitySensorValue(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(-1000000000,1000000000)

class EntitySensorStatus(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("ok", 1), ("unavailable", 2), ("nonoperational", 3),)

entPhySensorTable = MibTable((1, 3, 6, 1, 2, 1, 99, 1, 1), )
if mibBuilder.loadTexts: entPhySensorTable.setDescription('This table contains one row per physical sensor represented\n            by an associated row in the entPhysicalTable.')
entPhySensorEntry = MibTableRow((1, 3, 6, 1, 2, 1, 99, 1, 1, 1), ).setIndexNames((0, "ENTITY-MIB", "entPhysicalIndex"))
if mibBuilder.loadTexts: entPhySensorEntry.setDescription('Information about a particular physical sensor.\n\n\n\n            An entry in this table describes the present reading of a\n            sensor, the measurement units and scale, and sensor\n            operational status.\n\n            Entries are created in this table by the agent.  An entry\n            for each physical sensor SHOULD be created at the same time\n            as the associated entPhysicalEntry.  An entry SHOULD be\n            destroyed if the associated entPhysicalEntry is destroyed.')
entPhySensorType = MibTableColumn((1, 3, 6, 1, 2, 1, 99, 1, 1, 1, 1), EntitySensorDataType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhySensorType.setDescription('The type of data returned by the associated\n            entPhySensorValue object.\n\n            This object SHOULD be set by the agent during entry\n            creation, and the value SHOULD NOT change during operation.')
entPhySensorScale = MibTableColumn((1, 3, 6, 1, 2, 1, 99, 1, 1, 1, 2), EntitySensorDataScale()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhySensorScale.setDescription('The exponent to apply to values returned by the associated\n            entPhySensorValue object.\n\n            This object SHOULD be set by the agent during entry\n            creation, and the value SHOULD NOT change during operation.')
entPhySensorPrecision = MibTableColumn((1, 3, 6, 1, 2, 1, 99, 1, 1, 1, 3), EntitySensorPrecision()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhySensorPrecision.setDescription("The number of decimal places of precision in fixed-point\n            sensor values returned by the associated entPhySensorValue\n            object.\n\n            This object SHOULD be set to '0' when the associated\n            entPhySensorType value is not a fixed-point type: e.g.,\n            'percentRH(9)', 'rpm(10)', 'cmm(11)', or 'truthvalue(12)'.\n\n            This object SHOULD be set by the agent during entry\n            creation, and the value SHOULD NOT change during operation.")
entPhySensorValue = MibTableColumn((1, 3, 6, 1, 2, 1, 99, 1, 1, 1, 4), EntitySensorValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhySensorValue.setDescription('The most recent measurement obtained by the agent for this\n            sensor.\n\n            To correctly interpret the value of this object, the\n            associated entPhySensorType, entPhySensorScale, and\n            entPhySensorPrecision objects must also be examined.')
entPhySensorOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 99, 1, 1, 1, 5), EntitySensorStatus()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhySensorOperStatus.setDescription('The operational status of the sensor.')
entPhySensorUnitsDisplay = MibTableColumn((1, 3, 6, 1, 2, 1, 99, 1, 1, 1, 6), SnmpAdminString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhySensorUnitsDisplay.setDescription('A textual description of the data units that should be used\n            in the display of entPhySensorValue.')
entPhySensorValueTimeStamp = MibTableColumn((1, 3, 6, 1, 2, 1, 99, 1, 1, 1, 7), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhySensorValueTimeStamp.setDescription('The value of sysUpTime at the time the status and/or value\n            of this sensor was last obtained by the agent.')
entPhySensorValueUpdateRate = MibTableColumn((1, 3, 6, 1, 2, 1, 99, 1, 1, 1, 8), Unsigned32()).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: entPhySensorValueUpdateRate.setDescription('An indication of the frequency that the agent updates the\n            associated entPhySensorValue object, representing in\n            milliseconds.\n\n            The value zero indicates:\n\n                - the sensor value is updated on demand (e.g.,\n                  when polled by the agent for a get-request),\n                - the sensor value is updated when the sensor\n                  value changes (event-driven),\n                - the agent does not know the update rate.\n\n            ')
entitySensorCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 99, 3, 1))
entitySensorGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 99, 3, 2))
entitySensorCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 99, 3, 1, 1)).setObjects(*(("ENTITY-SENSOR-MIB", "entitySensorValueGroup"), ("ENTITY-MIB", "entityPhysicalGroup"),))
if mibBuilder.loadTexts: entitySensorCompliance.setDescription('Describes the requirements for conformance to the Entity\n            Sensor MIB module.')
entitySensorValueGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 99, 3, 2, 1)).setObjects(*(("ENTITY-SENSOR-MIB", "entPhySensorType"), ("ENTITY-SENSOR-MIB", "entPhySensorScale"), ("ENTITY-SENSOR-MIB", "entPhySensorPrecision"), ("ENTITY-SENSOR-MIB", "entPhySensorValue"), ("ENTITY-SENSOR-MIB", "entPhySensorOperStatus"), ("ENTITY-SENSOR-MIB", "entPhySensorUnitsDisplay"), ("ENTITY-SENSOR-MIB", "entPhySensorValueTimeStamp"), ("ENTITY-SENSOR-MIB", "entPhySensorValueUpdateRate"),))
if mibBuilder.loadTexts: entitySensorValueGroup.setDescription('A collection of objects representing physical entity sensor\n            information.')
mibBuilder.exportSymbols("ENTITY-SENSOR-MIB", EntitySensorDataType=EntitySensorDataType, entitySensorCompliance=entitySensorCompliance, entPhySensorValueUpdateRate=entPhySensorValueUpdateRate, entPhySensorOperStatus=entPhySensorOperStatus, EntitySensorValue=EntitySensorValue, entitySensorValueGroup=entitySensorValueGroup, entitySensorConformance=entitySensorConformance, entPhySensorScale=entPhySensorScale, entPhySensorEntry=entPhySensorEntry, entPhySensorValueTimeStamp=entPhySensorValueTimeStamp, entPhySensorPrecision=entPhySensorPrecision, entPhySensorType=entPhySensorType, entPhySensorValue=entPhySensorValue, entitySensorObjects=entitySensorObjects, PYSNMP_MODULE_ID=entitySensorMIB, EntitySensorStatus=EntitySensorStatus, entitySensorCompliances=entitySensorCompliances, entitySensorGroups=entitySensorGroups, entPhySensorTable=entPhySensorTable, EntitySensorDataScale=EntitySensorDataScale, entitySensorMIB=entitySensorMIB, entPhySensorUnitsDisplay=entPhySensorUnitsDisplay, EntitySensorPrecision=EntitySensorPrecision)



#
# PySNMP MIB module T11-FC-ROUTE-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/T11-FC-ROUTE-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:30:21 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsUnion, ValueSizeConstraint, ConstraintsIntersection, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsUnion", "ValueSizeConstraint", "ConstraintsIntersection", "ValueRangeConstraint")
( FcAddressIdOrZero, fcmInstanceIndex, FcDomainIdOrZero, fcmSwitchIndex, ) = mibBuilder.importSymbols("FC-MGMT-MIB", "FcAddressIdOrZero", "fcmInstanceIndex", "FcDomainIdOrZero", "fcmSwitchIndex")
( InterfaceIndex, InterfaceIndexOrZero, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex", "InterfaceIndexOrZero")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( MibIdentifier, iso, Unsigned32, TimeTicks, NotificationType, Integer32, IpAddress, mib_2, Bits, Counter64, Counter32, Gauge32, MibScalar, MibTable, MibTableRow, MibTableColumn, ModuleIdentity, ObjectIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibIdentifier", "iso", "Unsigned32", "TimeTicks", "NotificationType", "Integer32", "IpAddress", "mib-2", "Bits", "Counter64", "Counter32", "Gauge32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "ModuleIdentity", "ObjectIdentity")
( RowStatus, TextualConvention, TimeStamp, DisplayString, StorageType, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "TextualConvention", "TimeStamp", "DisplayString", "StorageType")
( T11FabricIndex, ) = mibBuilder.importSymbols("T11-TC-MIB", "T11FabricIndex")
t11FcRouteMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 144)).setRevisions(("2006-08-14 00:00",))
if mibBuilder.loadTexts: t11FcRouteMIB.setLastUpdated('200608140000Z')
if mibBuilder.loadTexts: t11FcRouteMIB.setOrganization('T11')
if mibBuilder.loadTexts: t11FcRouteMIB.setContactInfo('     Claudio DeSanti\n                    Cisco Systems, Inc.\n                    170 West Tasman Drive\n                    San Jose, CA 95134 USA\n                    EMail: cds@cisco.com\n\n\n                    Keith McCloghrie\n                    Cisco Systems, Inc.\n                    170 West Tasman Drive\n                    San Jose, CA USA 95134\n                    Email: kzm@cisco.com')
if mibBuilder.loadTexts: t11FcRouteMIB.setDescription('The MIB module for configuring and displaying Fibre\n           Channel Route Information.\n\n           Copyright (C) The Internet Society (2006).  This version\n           of this MIB module is part of RFC 4625;  see the RFC\n           itself for full legal notices.')
t11FcRouteNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 144, 0))
t11FcRouteObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 144, 1))
t11FcRouteConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 144, 2))
t11FcRouteFabricTable = MibTable((1, 3, 6, 1, 2, 1, 144, 1, 1), )
if mibBuilder.loadTexts: t11FcRouteFabricTable.setDescription('The table containing Fibre Channel Routing information\n           that is specific to a Fabric.')
t11FcRouteFabricEntry = MibTableRow((1, 3, 6, 1, 2, 1, 144, 1, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ROUTE-MIB", "t11FcRouteFabricIndex"))
if mibBuilder.loadTexts: t11FcRouteFabricEntry.setDescription('Each entry contains routing information specific to a\n           particular Fabric on a particular switch (identified by\n           values of fcmInstanceIndex and fcmSwitchIndex).')
t11FcRouteFabricIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 1, 1, 1), T11FabricIndex())
if mibBuilder.loadTexts: t11FcRouteFabricIndex.setDescription('A unique index value that uniquely identifies a\n           particular Fabric.\n\n           In a Fabric conformant to FC-SW-3, only a single Fabric\n\n\n\n           can operate within a physical infrastructure, and thus\n           the value of this Fabric Index will always be 1.\n\n           In a Fabric conformant to FC-SW-4, multiple Virtual Fabrics\n           can operate within one (or more) physical infrastructures.\n           In such a case, index value is used to uniquely identify a\n           particular Fabric within a physical infrastructure.')
t11FcRouteFabricLastChange = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 1, 1, 2), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11FcRouteFabricLastChange.setDescription('The value of sysUpTime at the most recent time when any\n           corresponding row in the t11FcRouteTable was created,\n           modified, or deleted.  A corresponding row in the\n           t11FcRouteTable is for the same management instance,\n           the same switch, and same Fabric as the row in this table.\n\n           If no change has occurred since the last restart of the\n           management system, then the value of this object is 0.')
t11FcRouteTable = MibTable((1, 3, 6, 1, 2, 1, 144, 1, 2), )
if mibBuilder.loadTexts: t11FcRouteTable.setDescription("The Fibre Channel Routing tables for the\n           locally managed switches.  This table lists all the\n           routes that are configured in and/or computed by any\n           local switch for any Fabric.\n\n           Such routes are used by a switch to forward frames (of user\n           data) on a Fabric.  The conceptual process is based on\n           extracting the Destination Fibre Channel Address Identifier\n           (D_ID) out of a received frame (of user data) and comparing\n           it to each entry of this table that is applicable to the\n           given switch and Fabric.  Such comparison consists of first\n           performing a logical-AND of the extracted D_ID with a mask\n           (the value of t11FcRouteDestMask) and second comparing the\n           result of that 'AND' operation to the value of\n           t11FcRouteDestAddrId.  A similar comparison is made of the\n           Source Fibre Channel Address Identifier (S_ID) of a frame\n\n\n\n           against the t11FcRouteSrcAddrId and t11FcRouteSrcMask values\n           of an entry.  If an entry's value of t11FcRouteInInterface\n           is non-zero, then a further comparison determines if the\n           frame was received on the appropriate interface.  If all of\n           these comparisons for a particular entry are successful,\n           then that entry represents a potential route for forwarding\n           the received frame.\n\n           For entries configured by a user, t11FcRouteProto has\n           the value 'netmgmt'; only entries of this type can be\n           deleted by the user.")
t11FcRouteEntry = MibTableRow((1, 3, 6, 1, 2, 1, 144, 1, 2, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "FC-MGMT-MIB", "fcmSwitchIndex"), (0, "T11-FC-ROUTE-MIB", "t11FcRouteFabricIndex"), (0, "T11-FC-ROUTE-MIB", "t11FcRouteDestAddrId"), (0, "T11-FC-ROUTE-MIB", "t11FcRouteDestMask"), (0, "T11-FC-ROUTE-MIB", "t11FcRouteSrcAddrId"), (0, "T11-FC-ROUTE-MIB", "t11FcRouteSrcMask"), (0, "T11-FC-ROUTE-MIB", "t11FcRouteInInterface"), (0, "T11-FC-ROUTE-MIB", "t11FcRouteProto"), (0, "T11-FC-ROUTE-MIB", "t11FcRouteOutInterface"))
if mibBuilder.loadTexts: t11FcRouteEntry.setDescription('Each entry contains a route to a particular destination,\n           possibly from a particular subset of source addresses,\n           on a particular Fabric via a particular output interface\n           and learned in a particular manner.')
t11FcRouteDestAddrId = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 2, 1, 1), FcAddressIdOrZero().subtype(subtypeSpec=ValueSizeConstraint(3,3)).setFixedLength(3))
if mibBuilder.loadTexts: t11FcRouteDestAddrId.setDescription('The destination Fibre Channel Address Identifier of\n           this route.  A zero-length string for this field is\n           not allowed.')
t11FcRouteDestMask = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 2, 1, 2), FcAddressIdOrZero())
if mibBuilder.loadTexts: t11FcRouteDestMask.setDescription("The mask to be logical-ANDed with a destination\n           Fibre Channel Address Identifier before it is compared\n           to the value in the t11FcRouteDestAddrId field.\n           Allowed values are 255.255.255, 255.255.0, or 255.0.0.\n           FSPF's definition generates routes to a Domain_ID,\n           so the mask for all FSPF-generated routes is 255.0.0.\n           The zero-length value has the same meaning as 0.0.0.")
t11FcRouteSrcAddrId = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 2, 1, 3), FcAddressIdOrZero())
if mibBuilder.loadTexts: t11FcRouteSrcAddrId.setDescription('The source Fibre Channel Address Identifier of this\n           route.  Note that if this object and the corresponding\n           instance of t11FcRouteSrcMask both have a value of 0.0.0,\n           then this route matches all source addresses.  The\n           zero-length value has the same meaning as 0.0.0.')
t11FcRouteSrcMask = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 2, 1, 4), FcAddressIdOrZero())
if mibBuilder.loadTexts: t11FcRouteSrcMask.setDescription('The mask to be logical-ANDed with a source\n           Fibre Channel Address Identifier before it is compared\n           to the value in the t11FcRouteSrcAddrId field.  Allowed\n           values are 255.255.255, 255.255.0, 255.0.0, or 0.0.0.\n           The zero-length value has the same meaning as 0.0.0.')
t11FcRouteInInterface = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 2, 1, 5), InterfaceIndexOrZero())
if mibBuilder.loadTexts: t11FcRouteInInterface.setDescription('If the value of this object is non-zero, it is the\n           value of ifIndex that identifies the local\n           Fibre Channel interface through which a frame\n           must have been received in order to match with\n           this entry.  If the value of this object is zero,\n           the matching does not require that the frame be\n           received on any specific interface.')
t11FcRouteProto = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 2, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("other", 1), ("local", 2), ("netmgmt", 3), ("fspf", 4),)))
if mibBuilder.loadTexts: t11FcRouteProto.setDescription('The mechanism via which this route was learned:\n                other(1)  - not specified\n                local(2)  - local interface\n                netmgmt(3)- static route\n                fspf(4)   - Fibre Shortest Path First\n           ')
t11FcRouteOutInterface = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 2, 1, 7), InterfaceIndex())
if mibBuilder.loadTexts: t11FcRouteOutInterface.setDescription('The value of ifIndex that identifies the local\n           Fibre Channel interface through which the next hop\n           of this route is to be reached.')
t11FcRouteDomainId = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 2, 1, 8), FcDomainIdOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FcRouteDomainId.setDescription("The domain_ID of next hop switch.\n\n           This object can have a value of zero if the value\n\n\n\n           of t11FcRouteProto is 'local'.")
t11FcRouteMetric = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 2, 1, 9), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,65536))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FcRouteMetric.setDescription('The routing metric for this route.\n\n           The use of this object is dependent on t11FcRouteProto.')
t11FcRouteType = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 2, 1, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("local", 1), ("remote", 2),)).clone('local')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FcRouteType.setDescription('The type of route.\n\n           local(1)  - a route for which the next Fibre Channel\n                       port is the final destination;\n           remote(2) - a route for which the next Fibre Channel\n                      port is not the final destination.')
t11FcRouteIfDown = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 2, 1, 11), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("remove", 1), ("retain", 2),)).clone('retain')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FcRouteIfDown.setDescription("The value of this object indicates what happens to\n           this route when the output interface (given by the\n           corresponding value of t11FcRouteOutInterface) is\n           operationally 'down'.  If this object's value is 'retain',\n           the route is to be retained in this table.  If this\n           object's value is 'remove', the route is to be removed\n           from this table.")
t11FcRouteStorageType = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 2, 1, 12), StorageType().clone('nonVolatile')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FcRouteStorageType.setDescription("The storage type for this conceptual row.\n           Conceptual rows having the value 'permanent' need not\n           allow write-access to any columnar objects in the row.")
t11FcRouteRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 144, 1, 2, 1, 13), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: t11FcRouteRowStatus.setDescription("The status of this conceptual row.\n           The only rows that can be deleted by setting this object to\n           'destroy' are those for which t11FcRouteProto has the value\n           'netmgmt'.")
t11FcRouteCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 144, 2, 1))
t11FcRouteGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 144, 2, 2))
t11FcRouteCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 144, 2, 1, 1)).setObjects(*(("T11-FC-ROUTE-MIB", "t11FcRouteGroup"),))
if mibBuilder.loadTexts: t11FcRouteCompliance.setDescription("The compliance statement for entities that\n           implement the T11-FC-ROUTE-MIB.\n--\n-- Note: The next four OBJECT clauses are for auxiliary objects, and the\n-- SMIv2 does not permit inclusion of objects that are not accessible\n-- in an OBJECT clause (see Sections 3.1 & 5.4.3 in STD 58, RFC 2580).\n-- Thus, these four clauses cannot be included below in the normal\n-- location for OBJECT clauses.\n--\n--      OBJECT     t11FcRouteSrcAddrId\n--      SYNTAX     FcAddressIdOrZero (SIZE (0))\n--      DESCRIPTION\n--             'Support is not required for routes that\n--             match only a subset of possible source\n\n\n\n--             addresses.'\n--\n--      OBJECT     t11FcRouteSrcMask\n--      SYNTAX     FcAddressIdOrZero (SIZE (0))\n--      DESCRIPTION\n--             'Support is not required for routes that\n--             match only a subset of possible source\n--             addresses.'\n--\n--      OBJECT     t11FcRouteDestMask\n--      DESCRIPTION\n--             'Support is mandatory only for FSPF-generated\n--             routes.  Since FSPF's definition generates\n--             routes to a Domain_ID, the mask for all\n--             FSPF-generated routes is 255.0.0.  Thus,\n--             support is only required for 255.0.0.'\n--\n--      OBJECT     t11FcRouteInInterface\n--      SYNTAX     InterfaceIndexOrZero (0)\n--      DESCRIPTION\n--             'Support for routes specific to particular\n--             source interfaces is not required.'\n          ")
t11FcRouteGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 144, 2, 2, 1)).setObjects(*(("T11-FC-ROUTE-MIB", "t11FcRouteFabricLastChange"), ("T11-FC-ROUTE-MIB", "t11FcRouteDomainId"), ("T11-FC-ROUTE-MIB", "t11FcRouteMetric"), ("T11-FC-ROUTE-MIB", "t11FcRouteType"), ("T11-FC-ROUTE-MIB", "t11FcRouteIfDown"), ("T11-FC-ROUTE-MIB", "t11FcRouteStorageType"), ("T11-FC-ROUTE-MIB", "t11FcRouteRowStatus"),))
if mibBuilder.loadTexts: t11FcRouteGroup.setDescription('A collection of objects for displaying and configuring\n           routes.')
mibBuilder.exportSymbols("T11-FC-ROUTE-MIB", t11FcRouteTable=t11FcRouteTable, PYSNMP_MODULE_ID=t11FcRouteMIB, t11FcRouteCompliances=t11FcRouteCompliances, t11FcRouteGroup=t11FcRouteGroup, t11FcRouteIfDown=t11FcRouteIfDown, t11FcRouteDestAddrId=t11FcRouteDestAddrId, t11FcRouteGroups=t11FcRouteGroups, t11FcRouteFabricIndex=t11FcRouteFabricIndex, t11FcRouteObjects=t11FcRouteObjects, t11FcRouteProto=t11FcRouteProto, t11FcRouteDomainId=t11FcRouteDomainId, t11FcRouteMIB=t11FcRouteMIB, t11FcRouteConformance=t11FcRouteConformance, t11FcRouteInInterface=t11FcRouteInInterface, t11FcRouteOutInterface=t11FcRouteOutInterface, t11FcRouteCompliance=t11FcRouteCompliance, t11FcRouteNotifications=t11FcRouteNotifications, t11FcRouteEntry=t11FcRouteEntry, t11FcRouteDestMask=t11FcRouteDestMask, t11FcRouteMetric=t11FcRouteMetric, t11FcRouteStorageType=t11FcRouteStorageType, t11FcRouteFabricTable=t11FcRouteFabricTable, t11FcRouteType=t11FcRouteType, t11FcRouteSrcMask=t11FcRouteSrcMask, t11FcRouteRowStatus=t11FcRouteRowStatus, t11FcRouteFabricLastChange=t11FcRouteFabricLastChange, t11FcRouteSrcAddrId=t11FcRouteSrcAddrId, t11FcRouteFabricEntry=t11FcRouteFabricEntry)



#
# PySNMP MIB module LANGTAG-TC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/LANGTAG-TC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:17:53 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, SingleValueConstraint, ValueSizeConstraint, ConstraintsIntersection, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsIntersection", "ConstraintsUnion")
( ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
( Counter32, Counter64, iso, mib_2, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, IpAddress, Gauge32, ObjectIdentity, Unsigned32, MibIdentifier, Integer32, ModuleIdentity, Bits, TimeTicks, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter32", "Counter64", "iso", "mib-2", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "IpAddress", "Gauge32", "ObjectIdentity", "Unsigned32", "MibIdentifier", "Integer32", "ModuleIdentity", "Bits", "TimeTicks")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
langTagTcMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 165)).setRevisions(("2007-11-09 00:00",))
if mibBuilder.loadTexts: langTagTcMIB.setLastUpdated('200711090000Z')
if mibBuilder.loadTexts: langTagTcMIB.setOrganization('IETF Operations and Management (OPS) Area')
if mibBuilder.loadTexts: langTagTcMIB.setContactInfo('EMail: ops-area@ietf.org\n                  Home page: http://www.ops.ietf.org/')
if mibBuilder.loadTexts: langTagTcMIB.setDescription('This MIB module defines a textual convention for\n            representing BCP 47 language tags.')
class LangTag(OctetString, TextualConvention):
    displayHint = '1a'
    subtypeSpec = OctetString.subtypeSpec+ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(2,63),)
mibBuilder.exportSymbols("LANGTAG-TC-MIB", PYSNMP_MODULE_ID=langTagTcMIB, langTagTcMIB=langTagTcMIB, LangTag=LangTag)
